Structs

Represents a single mutation onto a code unit to make it out of bounds.

Represents a single mutation to a CompiledModule to produce an out-of-bounds situation.

Enums

Represents the number of pointers that exist out from a node of a particular kind.

Statics