Enum invalid_mutations::bounds::PointerKind
source · [−]Expand description
Represents the number of pointers that exist out from a node of a particular kind.
Variants
One(IndexKind)
Exactly one pointer out with this index kind as its destination.
Optional(IndexKind)
Zero or one pointer out with this index kind as its destination. Like the ? operator in
regular expressions.
Star(IndexKind)
Zero or more pointers out with this index kind as its destination. Like the * operator
in regular expressions.
Implementations
sourceimpl PointerKind
impl PointerKind
sourcepub fn pointers_from(src_kind: IndexKind) -> &'static [PointerKind]
pub fn pointers_from(src_kind: IndexKind) -> &'static [PointerKind]
A list of what pointers (indexes) exist out from a particular kind of node within the module.
The only special case is FunctionDefinition, which contains a CodeUnit that can contain
one of several kinds of pointers out. That is not represented in this table.
pub fn to_index_kind(self) -> IndexKind